@@ -1,5 +1,9 @@
 #!/bin/sh
 
+PKGVER=`grep "Version:" ../DESCRIPTION | sed -e "s/Version: //"`
+sed -i -e "s/myversion{.*}/myversion{${PKGVER}}/" pbdDMAT-guide.Rnw
+
+
 rm *.aux *.bbl *.blg *.log *.out *.toc
 pdflatex pbdDMAT-guide.Rnw
 bibtex pbdDMAT-guide
@@ -7,7 +11,7 @@ bibtex pbdDMAT-guide
 #pdflatex pbdDMAT-guide.Rnw
 pdflatex pbdDMAT-guide.Rnw
 pdflatex pbdDMAT-guide.Rnw
-Rscript -e "tools::compactPDF('.', gs_quality='ebook')"
+Rscript -e "tools::compactPDF('pbdDMAT-guide.pdf', gs_quality='ebook')"
 rm *.aux *.bbl *.blg *.log *.out *.toc *.dvi
 
 mv -f *.pdf ../inst/doc/
